@@ -130,7 +130,7 @@ def nav_column(self, view, boxes, context):
 @monkeypatch(basetemplates.TheMainTemplate)
 def content_column(self, view, content_cols):
     w = self.w
-    w(u'<div class="col-md-%(col)s" role="main">' % {
+    w(u'<div id="main-center" class="col-md-%(col)s" role="main">' % {
         'col': content_cols})
     w(u'<div id="pageContent">')
     components = self._cw.vreg['components']
